@@ -1,7 +1,6 @@
 import os
 import threading
 import time
-from future.utils import with_metaclass, iteritems
 from itertools import chain
 from functools import wraps
 
@@ -40,9 +39,9 @@ class ExploitOptionsAggregator(type):
         except AttributeError:
             attrs["exploit_attributes"] = {}
         else:
-            attrs["exploit_attributes"] = {k: v for d in base_exploit_attributes for k, v in iteritems(d)}
+            attrs["exploit_attributes"] = {k: v for d in base_exploit_attributes for k, v in d.items()}
 
-        for key, value in iteritems(attrs.copy()):
+        for key, value in attrs.copy().items():
             if isinstance(value, Option):
                 value.label = key
                 attrs["exploit_attributes"].update({key: [value.display_value, value.description, value.advanced]})
@@ -55,7 +54,7 @@ class ExploitOptionsAggregator(type):
         return super(ExploitOptionsAggregator, cls).__new__(cls, name, bases, attrs)
 
 
-class BaseExploit(with_metaclass(ExploitOptionsAggregator, object)):
+class BaseExploit(metaclass=ExploitOptionsAggregator):
     @property
     def options(self):
         """ Returns list of options that user can set.
